import React$1, { SVGProps, Dispatch, ReactNode } from 'react';
import { z } from 'zod';

type IconSvgProps = SVGProps<SVGSVGElement> & {
    size?: number;
};
interface Event {
    id: string;
    title: string;
    description?: string;
    startDate: Date;
    endDate: Date;
    variant?: Variant;
}
interface SchedulerState {
    events: Event[];
}
type Action = {
    type: "ADD_EVENT";
    payload: Event;
} | {
    type: "REMOVE_EVENT";
    payload: {
        id: string;
    };
} | {
    type: "UPDATE_EVENT";
    payload: Event;
};
interface Handlers {
    handleEventStyling: (event: Event, dayEvents: Event[]) => {
        height: string;
        left: string;
        maxWidth: string;
        minWidth: string;
        top: string;
        zIndex: number;
    };
    handleAddEvent: (event: Event) => void;
    handleUpdateEvent: (event: Event, id: string) => void;
    handleDeleteEvent: (id: string) => void;
}
interface Getters {
    getDaysInMonth: (month: number, year: number) => {
        day: number;
        events: Event[];
    }[];
    getEventsForDay: (day: number, currentDate: Date) => Event[];
    getDaysInWeek: (week: number, year: number) => Date[];
    getWeekNumber: (date: Date) => number;
    getDayName: (day: number) => string;
}
interface SchedulerContextType {
    events: SchedulerState;
    dispatch: Dispatch<Action>;
    getters: Getters;
    handlers: Handlers;
}
declare const variants: readonly ["success", "primary", "default", "warning", "danger"];
type Variant = (typeof variants)[number];
declare const eventSchema: z.ZodObject<{
    title: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    startDate: z.ZodDate;
    endDate: z.ZodDate;
    variant: z.ZodEnum<["primary", "danger", "success", "warning", "default"]>;
    color: z.ZodString;
}, "strip", z.ZodTypeAny, {
    title: string;
    color: string;
    startDate: Date;
    endDate: Date;
    variant: "success" | "primary" | "default" | "warning" | "danger";
    description?: string | undefined;
}, {
    title: string;
    color: string;
    startDate: Date;
    endDate: Date;
    variant: "success" | "primary" | "default" | "warning" | "danger";
    description?: string | undefined;
}>;
type EventFormData = z.infer<typeof eventSchema>;
type Views = {
    mobileViews?: string[];
    views?: string[];
};
type startOfWeek = "sunday" | "monday";
interface CustomEventModal {
    CustomAddEventModal?: {
        title?: string;
        CustomForm?: React.FC<{
            register: any;
            errors: any;
        }>;
    };
}
interface CustomComponents {
    customButtons?: {
        CustomAddEventButton?: React.ReactNode;
        CustomPrevButton?: React.ReactNode;
        CustomNextButton?: React.ReactNode;
    };
    customTabs?: {
        CustomDayTab?: React.ReactNode;
        CustomWeekTab?: React.ReactNode;
        CustomMonthTab?: React.ReactNode;
    };
    CustomEventComponent?: React.FC<Event>;
    CustomEventModal?: CustomEventModal;
}
interface ButtonClassNames {
    prev?: string;
    next?: string;
    addEvent?: string;
}
interface TabClassNames {
    view?: string;
}
interface TabsClassNames {
    cursor?: string;
    panel?: string;
    tab?: string;
    tabContent?: string;
    tabList?: string;
    wrapper?: string;
}
interface ViewClassNames {
    dayView?: string;
    weekView?: string;
    monthView?: string;
}
interface ClassNames {
    event?: string;
    buttons?: ButtonClassNames;
    tabs?: TabsClassNames;
    views?: ViewClassNames;
}

declare const SchedulerProvider: ({ children, onAddEvent, onUpdateEvent, onDeleteEvent, weekStartsOn, }: {
    onAddEvent?: ((event: Event) => void) | undefined;
    onUpdateEvent?: ((event: Event) => void) | undefined;
    onDeleteEvent?: ((id: string) => void) | undefined;
    weekStartsOn?: startOfWeek | undefined;
    children: ReactNode;
}) => React$1.JSX.Element;
declare const useScheduler: () => SchedulerContextType;

declare function SchedulerViewFilteration({ views, CustomComponents, classNames, }: {
    views?: Views;
    CustomComponents?: CustomComponents;
    classNames?: ClassNames;
}): React$1.JSX.Element;

export { type Action, type ButtonClassNames, type ClassNames, type CustomComponents, type CustomEventModal, type Event, type EventFormData, type Getters, type Handlers, type IconSvgProps, SchedulerViewFilteration as SchedularView, type SchedulerContextType, SchedulerProvider, type SchedulerState, type TabClassNames, type TabsClassNames, type Variant, type ViewClassNames, type Views, eventSchema, type startOfWeek, useScheduler, variants };
